package com.bonus.canteen.core.nutrition.service;

import java.util.List;
import com.bonus.canteen.core.nutrition.domain.HealthArticleChronic;

/**
 * 健康科普慢性病关联Service接口
 * 
 * @author xsheng
 * @date 2025-05-13
 */
public interface IHealthArticleChronicService {
    /**
     * 查询健康科普慢性病关联
     * 
     * @param id 健康科普慢性病关联主键
     * @return 健康科普慢性病关联
     */
    public HealthArticleChronic selectHealthArticleChronicById(Long id);

    /**
     * 查询健康科普慢性病关联列表
     * 
     * @param healthArticleChronic 健康科普慢性病关联
     * @return 健康科普慢性病关联集合
     */
    public List<HealthArticleChronic> selectHealthArticleChronicList(HealthArticleChronic healthArticleChronic);

    /**
     * 新增健康科普慢性病关联
     * 
     * @param healthArticleChronic 健康科普慢性病关联
     * @return 结果
     */
    public int insertHealthArticleChronic(HealthArticleChronic healthArticleChronic);

    /**
     * 修改健康科普慢性病关联
     * 
     * @param healthArticleChronic 健康科普慢性病关联
     * @return 结果
     */
    public int updateHealthArticleChronic(HealthArticleChronic healthArticleChronic);

    /**
     * 批量删除健康科普慢性病关联
     * 
     * @param ids 需要删除的健康科普慢性病关联主键集合
     * @return 结果
     */
    public int deleteHealthArticleChronicByIds(Long[] ids);

    /**
     * 删除健康科普慢性病关联信息
     * 
     * @param id 健康科普慢性病关联主键
     * @return 结果
     */
    public int deleteHealthArticleChronicById(Long id);
}
