package com.bonus.canteen.core.nutrition.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.canteen.core.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.nutrition.domain.HealthArticleChronic;
import com.bonus.canteen.core.nutrition.service.IHealthArticleChronicService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 健康科普慢性病关联Controller
 * 
 * @author xsheng
 * @date 2025-05-13
 */
@Api(tags = "健康科普慢性病关联接口")
@RestController
@RequestMapping("/health_article_chronic")
public class HealthArticleChronicController extends BaseController {
    @Autowired
    private IHealthArticleChronicService healthArticleChronicService;

    /**
     * 查询健康科普慢性病关联列表
     */
    @ApiOperation(value = "查询健康科普慢性病关联列表")
    //@RequiresPermissions("nutrition:chronic:list")
    @GetMapping("/list")
    public TableDataInfo list(HealthArticleChronic healthArticleChronic) {
        startPage();
        List<HealthArticleChronic> list = healthArticleChronicService.selectHealthArticleChronicList(healthArticleChronic);
        return getDataTable(list);
    }

    /**
     * 导出健康科普慢性病关联列表
     */
    @ApiOperation(value = "导出健康科普慢性病关联列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("nutrition:chronic:export")
    @SysLog(title = "健康科普慢性病关联", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出健康科普慢性病关联")
    @PostMapping("/export")
    public void export(HttpServletResponse response, HealthArticleChronic healthArticleChronic) {
        List<HealthArticleChronic> list = healthArticleChronicService.selectHealthArticleChronicList(healthArticleChronic);
        ExcelUtil<HealthArticleChronic> util = new ExcelUtil<HealthArticleChronic>(HealthArticleChronic.class);
        util.exportExcel(response, list, "健康科普慢性病关联数据");
    }

    /**
     * 获取健康科普慢性病关联详细信息
     */
    @ApiOperation(value = "获取健康科普慢性病关联详细信息")
    //@RequiresPermissions("nutrition:chronic:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(healthArticleChronicService.selectHealthArticleChronicById(id));
    }

    /**
     * 新增健康科普慢性病关联
     */
    @ApiOperation(value = "新增健康科普慢性病关联")
    //@PreventRepeatSubmit
    //@RequiresPermissions("nutrition:chronic:add")
    @SysLog(title = "健康科普慢性病关联", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增健康科普慢性病关联")
    @PostMapping
    public AjaxResult add(@RequestBody HealthArticleChronic healthArticleChronic) {
        try {
            return toAjax(healthArticleChronicService.insertHealthArticleChronic(healthArticleChronic));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改健康科普慢性病关联
     */
    @ApiOperation(value = "修改健康科普慢性病关联")
    //@PreventRepeatSubmit
    //@RequiresPermissions("nutrition:chronic:edit")
    @SysLog(title = "健康科普慢性病关联", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改健康科普慢性病关联")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody HealthArticleChronic healthArticleChronic) {
        try {
            return toAjax(healthArticleChronicService.updateHealthArticleChronic(healthArticleChronic));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除健康科普慢性病关联
     */
    @ApiOperation(value = "删除健康科普慢性病关联")
    //@PreventRepeatSubmit
    //@RequiresPermissions("nutrition:chronic:remove")
    @SysLog(title = "健康科普慢性病关联", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除健康科普慢性病关联")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(healthArticleChronicService.deleteHealthArticleChronicByIds(ids));
    }
}
